@@ -1,7 +1,7 @@
 /*
     Swephelp
 
-    Copyright 2007-2009 Stanislas Marquis <stnsls@gmail.com>
+    Copyright 2007-2011 Stanislas Marquis <stnsls@gmail.com>
 
     Swephelp is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -26,7 +26,9 @@ extern "C"
 #endif
 
 #include "swhraman.h"
-#include <swephexp.h>
+
+#include <stdlib.h>
+
 #include "swhdef.h"
 
 /** @brief Get Raman houses cusps
